@@ -9,7 +9,8 @@ SEXP rcpp_make_geometries(
     SEXP id_cols,
     SEXP geometry_cols,
     Rcpp::List attributes,
-    bool close
+    bool close,
+    bool closed_attribute
   ) {
-  return geometries::make_geometries( x, id_cols, geometry_cols, attributes, close );
+  return geometries::make_geometries( x, id_cols, geometry_cols, attributes, close, closed_attribute );
 }
